@@ -27,27 +27,28 @@ nu[M+1,M] <- +1
 # Propensity vector
 a <- as.vector(paste("c*x",seq(M),"",sep=""))
 
-tf <- 10 # Final time
+tf <- 5 # Final time
 simName <- "Linear Chain System"
 
 # Run the simulations
+nf <- layout(matrix(c(1,2,3,4),ncol=2, byrow=T))
 
 # Direct method
 set.seed(1)
-out <- ssa(x0,a,nu,parms,tf,method="D",simName,maxWallTime=5)
-ssa.plot(out)
+out <- ssa(x0,a,nu,parms,tf,method="D",simName,verbose=TRUE,consoleInterval=1)
+ssa.plot(out,show.title=TRUE,show.legend=FALSE)
 
 # Explict tau-leap method
 set.seed(1)
-out <- ssa(x0,a,nu,parms,tf,method="ETL",simName,tau=0.1,maxWallTime=5)
-ssa.plot(out)
+out <- ssa(x0,a,nu,parms,tf,method="ETL",simName,tau=0.1,verbose=TRUE,consoleInterval=1)
+ssa.plot(out,show.title=FALSE,show.legend=FALSE)
 
 # Binomial tau-leap method
 set.seed(1)
-out <- ssa(x0,a,nu,parms,tf,method="BTL",simName,f=50,maxWallTime=5)
-ssa.plot(out)
+out <- ssa(x0,a,nu,parms,tf,method="BTL",simName,f=50,verbose=TRUE,consoleInterval=1)
+ssa.plot(out,show.title=FALSE,show.legend=FALSE)
 
 # Optimal tau-leap method
 set.seed(1)
-out <- ssa(x0,a,nu,parms,tf,method="OTL",simName,maxWallTime=5)
-ssa.plot(out)
+out <- ssa(x0,a,nu,parms,tf,method="OTL",simName,verbose=TRUE,consoleInterval=1)
+ssa.plot(out,show.title=FALSE,show.legend=FALSE)
