@@ -25,23 +25,24 @@ tf <- 10                          # Final time
 simName <- "Logistic growth" 
 
 # Run the simulations
+nf <- layout(matrix(c(1,2,3,4),ncol=2, byrow=T))
 
 # Direct method
 set.seed(1)
-out <- ssa(x0,a,nu,parms,tf,method="D",simName,maxWallTime=10)
-ssa.plot(out) 
+out <- ssa(x0,a,nu,parms,tf,method="D",simName,verbose=TRUE,consoleInterval=1)
+ssa.plot(out,show.title=TRUE,show.legend=FALSE) 
  
 # Explict tau-leap method
 set.seed(1)
-out <- ssa(x0,a,nu,parms,tf,method="ETL",simName,tau=0.03,maxWallTime=5)
-ssa.plot(out) 
+out <- ssa(x0,a,nu,parms,tf,method="ETL",simName,tau=0.03,verbose=TRUE,consoleInterval=1)
+ssa.plot(out,show.title=FALSE,show.legend=FALSE) 
 
 # Run the simulation using the Binomial tau-leap method 
 set.seed(1)
-out <- ssa(x0,a,nu,parms,tf,method="BTL",simName,f=5,maxWallTime=5)
-ssa.plot(out) 
+out <- ssa(x0,a,nu,parms,tf,method="BTL",simName,f=5,verbose=TRUE,consoleInterval=1)
+ssa.plot(out,show.title=FALSE,show.legend=FALSE) 
 
 # Optimized tau-leap method
 set.seed(1)
-out <- ssa(x0,a,nu,parms,tf,method="OTL",simName,maxWallTime=5)
-ssa.plot(out)
+out <- ssa(x0,a,nu,parms,tf,method="OTL",simName,verbose=TRUE,consoleInterval=1)
+ssa.plot(out,show.title=FALSE,show.legend=FALSE)
