@@ -24,23 +24,24 @@ tf <- 100                                     # Final time
 simName <- "Kermack-McKendrick SIR"
 
 # Run the simulations
+nf <- layout(matrix(c(1,2,3,4),ncol=2, byrow=T))
 
 # Direct method
 set.seed(2)
-out <- ssa(x0,a,nu,parms,tf,method="D",simName)
-ssa.plot(out) 
+out <- ssa(x0,a,nu,parms,tf,method="D",simName,verbose=TRUE,consoleInterval=1)
+ssa.plot(out,show.title=TRUE,show.legend=TRUE) 
 
 # Explicit tau-leap method
 set.seed(2)
-out <- ssa(x0,a,nu,parms,tf,method="ETL",simName)
-ssa.plot(out) 
+out <- ssa(x0,a,nu,parms,tf,method="ETL",simName,verbose=TRUE,consoleInterval=1)
+ssa.plot(out,show.title=FALSE,show.legend=FALSE) 
 
 # Binomial tau-leap method
 set.seed(2)
-out <- ssa(x0,a,nu,parms,tf,method="BTL",simName)
-ssa.plot(out) 
+out <- ssa(x0,a,nu,parms,tf,method="BTL",simName,verbose=TRUE,consoleInterval=1)
+ssa.plot(out,show.title=FALSE,show.legend=FALSE) 
 
 # Optimized tau-leap method
 set.seed(2)
-out <- ssa(x0,a,nu,parms,tf,method="OTL",simName)
-ssa.plot(out) 
+out <- ssa(x0,a,nu,parms,tf,method="OTL",simName,verbose=TRUE,consoleInterval=1)
+ssa.plot(out,show.title=FALSE,show.legend=FALSE) 
